@@ -308,8 +308,9 @@ cal_read_ccpompnents_for_type(CCalendar* calendar,
 				  end_time);
     if(instance_times.empty())
       all_components.insert(component);
-    else
+    else if(type!=4)
     {
+      
       for(vector<time_t>::const_iterator iter = instance_times.begin();
 	  iter!=instance_times.end();
 	  ++iter)
@@ -343,11 +344,11 @@ cal_read_ccomponents_all_visible(SortedCComponentSet& all_components,
 				    start_time,
 				    end_time,
 				    all_components);
-      cal_read_ccpompnents_for_type(cal,
-				    4,
-				    start_time,
-				    end_time,
-				    all_components);
+       cal_read_ccpompnents_for_type(cal, 
+				    4, 
+ 				    start_time, 
+ 				    end_time, 
+ 				    all_components); 
     }
     delete cal;
   }
