@@ -25,6 +25,8 @@
 #include "cal-home-calendar-util.h"
 #include "cal-home-load-and-store.h"
 
+void
+cal_widget_resize_for_cal_size(CalHomePlugin* desktop_plugin);
 
 static GtkWidget*
 create_calendar_colour_icon_image(CalendarColour colour, GtkIconSize icon_size)
@@ -77,7 +79,7 @@ show_visible_calendars_dlg(GtkButton* button, gpointer data)
   int i = 0;
   while(calendars_iter!=calendars_iter_end)
   {
-    GtkWidget* check_button = hildon_gtk_toggle_button_new(HILDON_SIZE_THUMB_HEIGHT);
+    GtkWidget* check_button = hildon_gtk_toggle_button_new(HILDON_SIZE_FINGER_HEIGHT);
 
     check_buttons[i] = check_button;      
 
@@ -91,21 +93,23 @@ show_visible_calendars_dlg(GtkButton* button, gpointer data)
     }
 
     gtk_button_set_label(GTK_BUTTON(check_button),
-			 //			 g_strdup((*calendars_iter)->getCalendarName().c_str()));
 			 (*calendars_iter)->getCalendarName().c_str());
 
     GtkWidget* image = create_calendar_colour_icon_image((*calendars_iter)->getCalendarColor(),
 							 HILDON_ICON_SIZE_FINGER);
     gtk_button_set_image(GTK_BUTTON(check_button), image);
     gtk_button_set_alignment(GTK_BUTTON(check_button),0 ,0);
+    gtk_box_pack_start(GTK_BOX(list_box), check_button, TRUE, FALSE, 0);
 
-    gtk_box_pack_start(GTK_BOX(list_box), check_button, TRUE, TRUE, 0);
     ++calendars_iter;
     ++i;
   }
 
+  GtkWidget* pan = hildon_pannable_area_new();
+  hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pan), list_box);
+  gtk_box_pack_start(GTK_BOX(content), pan, TRUE, TRUE, 0);
   gtk_box_pack_start(GTK_BOX(content), list_box, TRUE, TRUE, 0);
-
+  gtk_window_set_default_size(GTK_WINDOW(dialog), -1, 325);  
   gtk_widget_show_all(dialog);
 
   if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
@@ -268,6 +272,7 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
     desktop_plugin->cal_time_period = CalTimePeriod(hildon_touch_selector_get_active(HILDON_TOUCH_SELECTOR(cal_time_selector), 0));
     cal_home_save_settings(desktop_plugin);
     cal_home_load_db_events(desktop_plugin);
+    cal_widget_resize_for_cal_size(desktop_plugin);
   }
   g_free(settings_data);
   gtk_widget_destroy (dialog);
